from .special import *
from .slugify import *
from .__version__ import __title__
from .__version__ import __author__
from .__version__ import __author_email__
from .__version__ import __description__
from .__version__ import __url__
from .__version__ import __license__
from .__version__ import __copyright__
from .__version__ import __version__
